FlutterAssets class

Inheritance

Constructors

FlutterAssets()

Properties

cache List<ImageReference>
finalinherited
client ↔ Client
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearCache() → void
inherited
getCache(ImageReference img) Uint8List?
inherited
getImageData(ImageReference img) Future<Uint8List?>
override
getImageSize(ImageReference img) Future<Size?>
inherited
hasCache(ImageReference img) bool
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeCache(ImageReference img) → void
inherited
setCache(ImageReference img, Uint8List bytes) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited