FlutterPowerPoint class

Available extensions

Constructors

FlutterPowerPoint()

Properties

author String?
getter/setter pairinherited
company String?
getter/setter pairinherited
context PresentationContext
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
layout ↔ Layout
getter/setter pairinherited
revision String?
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showSlideNumbers bool
getter/setter pairinherited
slides List<Slide>
getter/setter pairinherited
subject String?
getter/setter pairinherited
title String?
getter/setter pairinherited

Methods

addAgendaSlide({TextValue? title, TextValue? subtitle, TextValue? topics}) Slide

Available on PowerPoint, provided by the SlideTemplates extension

addBigFactSlide({TextValueLine? fact, TextValue? information}) Slide

Available on PowerPoint, provided by the SlideTemplates extension

addBlankSlide() Slide

Available on PowerPoint, provided by the SlideTemplates extension

addBulletsSlide({List<TextValue> bullets = const []}) Slide

Available on PowerPoint, provided by the SlideTemplates extension

addPhoto3UpSlide({ImageReference? image1, ImageReference? image2, ImageReference? image3}) Slide

Available on PowerPoint, provided by the SlideTemplates extension

addPhotoSlide({ImageReference? image}) Slide

Available on PowerPoint, provided by the SlideTemplates extension

addQuoteSlide({TextValueLine? quote, TextValue? attribution}) Slide

Available on PowerPoint, provided by the SlideTemplates extension

addSectionSlide({TextValue? section}) Slide

Available on PowerPoint, provided by the SlideTemplates extension

addSlide(Slide slide, {TextValue? notes, bool? showSlideNumbers}) Slide
inherited
addSlidesFromMarkdown(String markdown) Future<List<Slide>>
inherited
addStatementSlide({TextValue? statement}) Slide

Available on PowerPoint, provided by the SlideTemplates extension

addTitleAndBulletsSlide({TextValue? title, List<TextValue> bullets = const [], TextValue? subtitle}) Slide

Available on PowerPoint, provided by the SlideTemplates extension

addTitleAndPhotoAltSlide({ImageReference? image, TextValue? title, TextValue? subtitle}) Slide

Available on PowerPoint, provided by the SlideTemplates extension

addTitleAndPhotoSlide({TextValue? title, ImageReference? image, TextValue? author, TextValue? subtitle}) Slide

Available on PowerPoint, provided by the SlideTemplates extension

addTitleBulletsAndPhotoSlide({TextValue? title, List<TextValue> bullets = const [], ImageReference? image, TextValue? subtitle}) Slide

Available on PowerPoint, provided by the SlideTemplates extension

addTitleOnlySlide({TextValue? title, TextValue? subtitle}) Slide

Available on PowerPoint, provided by the SlideTemplates extension

addTitleSlide({TextValue? title, TextValue? author}) Slide

Available on PowerPoint, provided by the SlideTemplates extension

addWidgetSlide(Widget builder(Size size), {Duration delay = const Duration(seconds: 1), double? pixelRatio, BuildContext? context, Size? targetSize}) Future<Slide>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
save() Future<Uint8List?>
inherited
setLayout(Layout layout) → void
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited